__progname__ = "nbserve"
__version__ = '0.1.0'
__description__ = """nbserve is a simple script that lets you serve
iPython notebooks as read-only HTML files over the web. It has some
default options that make the notebooks appropriate for generating
reports, such as hiding input cells."""
__author__ = 'Rob Chambers'
__author_email__ = 'rdchambers@gmail.com'
__url__ = 'https://github.com/robchambers/nbserve'
__keywords__ = ['iPython', 'notebook', 'flask', 'server']